window {
    border-bottom-left-radius: 7px;
    border-bottom-right-radius: 7px;
}

.homepage button {
    transition: border 100ms ease-in-out;
    padding: 10px 30px;
    border: none;
    border-radius: 5px 5px 5px 5px;
}

.aboutdialog {
    border-radius: 7px;
}